@@ -33,12 +33,10 @@ SEXP py_tuple_to_r_list(PyObject *py_object, int simplify);
 
 SEXP py_dict_to_r_list(PyObject *py_object, int simplify);
 
-long py_to_c_integer(PyObject *py_object);
+int py_to_c_integer(PyObject *py_object);
 
 const char *py_to_c_string(PyObject *py_object);
 
-SEXP py_to_r_simple(PyObject *py_object);
-
 SEXP py_to_r(PyObject *py_object, int simplify, int autotype);
 
 #endif
